==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeErrorFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public class V1beta1VolumeErrorFluentImpl<A extends V1beta1VolumeErrorFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1VolumeErrorFluent<A>{

    private String message;
    private DateTime time;

    public V1beta1VolumeErrorFluentImpl(){
    }
    public V1beta1VolumeErrorFluentImpl(V1beta1VolumeError instance){
            this.withMessage(instance.getMessage());

            this.withTime(instance.getTime());

    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public DateTime getTime(){
            return this.time;
    }

    public A withTime(DateTime time){
            this.time=time; return (A) this;
    }

    public Boolean hasTime(){
            return this.time != null;
    }

    public A withNewTime(int arg0,int arg1,int arg2,int arg3,int arg4){
            return (A)withTime(new DateTime(arg0, arg1, arg2, arg3, arg4));
    }

    public A withNewTime(long arg0){
            return (A)withTime(new DateTime(arg0));
    }

    public A withNewTime(Object arg0){
            return (A)withTime(new DateTime(arg0));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1VolumeErrorFluentImpl that = (V1beta1VolumeErrorFluentImpl) o;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (time != null ? !time.equals(that.time) :that.time != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeErrorFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public class V1beta1VolumeErrorFluentImpl<A extends V1beta1VolumeErrorFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1VolumeErrorFluent<A>{

    private String message;
    private DateTime time;

    public V1beta1VolumeErrorFluentImpl(){
    }
    public V1beta1VolumeErrorFluentImpl(V1beta1VolumeError instance){
            this.withMessage(instance.getMessage());

            this.withTime(instance.getTime());

    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public A withNewMessage(String arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1){
            return (A)withMessage(new String(arg1));
    }

    public DateTime getTime(){
            return this.time;
    }

    public A withTime(DateTime time){
            this.time=time; return (A) this;
    }

    public Boolean hasTime(){
            return this.time != null;
    }

    public A withNewTime(int arg0,int arg1,int arg2,int arg3,int arg4){
            return (A)withTime(new DateTime(arg0, arg1, arg2, arg3, arg4));
    }

    public A withNewTime(Object arg0){
            return (A)withTime(new DateTime(arg0));
    }

    public A withNewTime(long arg0){
            return (A)withTime(new DateTime(arg0));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1VolumeErrorFluentImpl that = (V1beta1VolumeErrorFluentImpl) o;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (time != null ? !time.equals(that.time) :that.time != null) return false;
            return true;
    }




}
